@@ -1,7 +1,7 @@
 #########################################################################################
 # Description:  Build Exec Scripts
 # Created       Sat Feb 23 17:21:10 2013
-# svn id        $Id: buildexecs.pl 1601 2013-03-19 11:39:40Z Mark Dootson $
+# svn id        $Id: buildexecs.pl 1738 2013-04-23 23:50:25Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -13,7 +13,7 @@ use strict;
 use warnings;
 use HiPi::Utils::Exec;
 
-for my $file ( qw( suidbin/hipi-i2c ) ) {
+for my $file ( qw( suidbin/hipi-i2c suidbin/hipi-pud ) ) {
     my @paths = split(/\//, $file);
     my $execname  = pop @paths;
     my $directory = join('/', @paths);
