@@ -2,7 +2,7 @@
 # Package       HiPi::Apps::Control::Panel::Pad
 # Description:  Base for GPIO Pad panels
 # Created       Wed Feb 27 23:09:33 2013
-# SVN Id        $Id: Pad.pm 1076 2013-03-13 08:55:10Z Mark Dootson $
+# SVN Id        $Id: Pad.pm 1712 2013-03-25 16:25:58Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -367,7 +367,8 @@ sub _draw_selected_pin {
     my $brush = wxTRANSPARENT_BRUSH;
     $dc->SetPen( $pen );
     $dc->SetBrush ( $brush );
-    my $pin = $self->pindata->[$self->selectedpin];
+    my $pinindex = $self->selectedpin || 0;
+    my $pin = $self->pindata->[$pinindex];
     $dc->DrawRectangle($pin->{focusrect}->x, $pin->{focusrect}->y, $pin->{focusrect}->GetWidth, $pin->{focusrect}->GetHeight);
 }
 
